package com.caimei.controller;

import com.alibaba.fastjson.JSONObject;
import com.caimei.model.ResponseJson;
import com.caimei.model.dto.BuyerUserDto;
import com.caimei.model.vo.BuyerUserVo;
import com.caimei.service.LoginService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * Description
 *
 * @author : plf
 * @date : 2021/3/22
 */
@Api(tags = "登录")
@RestController
@RequestMapping("/buyer")
public class LoginApi {

    private LoginService loginService;

    @Autowired
    public void setLoginService(LoginService loginService) {
        this.loginService = loginService;
    }

    /**
     * 小程序授权登录
     *
     * @param params {"code":"" } code小程序登录唯一凭证
     */
    @ApiOperation("授权登录")
    @PostMapping("/authorization")
    @ApiImplicitParam(name = "params", value = "code登录凭证", required = true)
    public ResponseJson<BuyerUserVo> authorizationLogin(@RequestBody String params) {
        JSONObject parseObject = JSONObject.parseObject(params);
        String code = parseObject.getString("code");
        if (StringUtils.isEmpty(code)) {
            return ResponseJson.error("参数异常", null);
        }
        return loginService.authorizationLogin(code);
    }

    /**
     * 邀请码登录
     */
    @ApiOperation("邀请码登录")
    @PostMapping("/invitation/code")
    public ResponseJson<BuyerUserVo> invitationCode(@RequestBody BuyerUserDto buyerUserDto) {
        if (StringUtils.isEmpty(buyerUserDto.getInvitationCode()) || StringUtils.isEmpty(buyerUserDto.getOpenid())
                || StringUtils.isEmpty(buyerUserDto.getNickName())) {
            return ResponseJson.error("参数异常", null);
        }
        return loginService.invitationCode(buyerUserDto);
    }

    /**
     * 个人中心数据
     */
    @ApiOperation("个人中心数据")
    @ApiImplicitParam(name = "organizeId", value = "组织id", required = true)
    @GetMapping("/personal")
    public ResponseJson<Map<String, Object>> personalData(Integer organizeId) {
        if (organizeId == null) {
            return ResponseJson.error("参数异常", null);
        }
        return loginService.personalData(organizeId);
    }
}
