package com.caimei.controller;


import com.alibaba.fastjson.JSONObject;
import com.caimei.config.WxConfig;
import com.caimei.model.ResponseJson;
import com.caimei.model.dto.PaymentDto;
import com.caimei.model.vo.OrderPayLinkVo;
import com.caimei.service.PayOrderService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpHeaders;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.reactive.function.server.ServerRequest;

import java.util.Map;

/**
 * Description
 *
 * @author : plf
 * @date : 2020/5/6
 */
@Api(tags = "订单支付")
@Slf4j
@RestController
@RequestMapping("/PayOrder")
public class PayOrderApi {
    private PayOrderService payOrderService;

    @Autowired
    public void setPayOrderService(PayOrderService payOrderService) {
        this.payOrderService = payOrderService;
    }

    @Value("${caimei.notifyUrl}")
    private String notifyUrl;

    @Value("${caimei.redirectLink}")
    private String redirectLink;

    /**
     * 获取线上支付开关状态
     *
     * @return
     */
    @ApiOperation("获取线上支付开关状态")
    @GetMapping("/onLineSwitch")
    public ResponseJson<Integer> onLineSwitch() {
        return payOrderService.getPayOnLineSwitch();
    }

    /**
     * 收银台数据显示
     */
    @GetMapping("/checkoutCounter")
    public ResponseJson<Map<String, Object>> checkoutCounter(Integer orderId) {
        if (null == orderId) {
            return ResponseJson.error("参数异常", null);
        }
        return payOrderService.checkoutCounter(orderId);
    }

    /**
     * 微信线上支付
     */
    @ApiOperation("微信线上支付")
    @PostMapping("/miniWxPay")
    public ResponseJson<JSONObject> miniWxPay(@RequestBody PaymentDto payment, @RequestHeader HttpHeaders headers) {
        if (!"WEIXIN".equals(payment.getPayWay()) || payment.getPayAmount() == null || payment.getPayAmount() < 2) {
            return ResponseJson.error("参数异常", null);
        }
        String clientIp = headers.getFirst("X-CLIENT-IP");
        payment.setClientIp(clientIp);
        Map<String, Object> map = null;
        if (null == payment.getState()) {
            //小程序微信快捷支付
            payment.setPayType("MINIAPP_WEIXIN");
            String infos;
            try {
                infos = WxConfig.getWxMallOpenId(payment.getCode());
            } catch (Exception e) {
                log.error("错误信息", e);
                return ResponseJson.error("wx小程序获取openid失败", null);
            }
            map = JSONObject.parseObject(infos, Map.class);
        } else {
            //pc微信扫码支付,微信公众号支付
            payment.setPayType("JSAPI_WEIXIN");
            try {
                map = WxConfig.getAccessTokenMap(payment.getCode());
            } catch (Exception e) {
                log.error("错误信息", e);
                return ResponseJson.error("wx公众号获取openid失败", null);
            }
        }
        String openid = (String) map.get("openid");
        if (openid == null) {
            return ResponseJson.error("wx获取openid失败", null);
        }
        payment.setOpenid(openid);
        payment.setNotifyUrl(notifyUrl);
        log.info("wx支付openid>>>>>" + openid);
        return payOrderService.pay(payment);
    }

    /**
     * 支付异步通知回调
     */
    @GetMapping("/paymentCallback")
    public String paymentCallback(ServerRequest request) throws Exception {
        log.info("异步回调通知>>>>>>>start");
        String data = request.pathVariable("data");
        if (StringUtils.isBlank(data)) {
            return "回调参数失败";
        }
        return payOrderService.paymentCallback(data);
    }

    /**
     * 小程序生成网银支付链接
     */
    @ApiOperation("小程序生成网银支付链接")
    @PostMapping("/payLink")
    public ResponseJson<String> payLink(@RequestBody OrderPayLinkVo orderPayLink) {
        orderPayLink.setRedirectLink(redirectLink);
        return payOrderService.payLink(orderPayLink);
    }

    /**
     * pc端支付,银联,支付宝
     */
    @ApiOperation("pc端支付,银联,支付宝支付")
    @PostMapping("/pcMallPay")
    public ResponseJson<JSONObject> pcMallPay(@RequestBody PaymentDto payment) {
        if (null == payment || StringUtils.isBlank(payment.getPayWay()) || StringUtils.isBlank(payment.getReturnUrl()) || payment.getPayAmount() == null) {
            return ResponseJson.error("参数异常", null);
        }
        if ("UNIONPAY".equals(payment.getPayWay())) {
            //银联支付
            payment.setPayType("GATEWAY_UNIONPAY");
        } else if ("ALIPAY".equals(payment.getPayWay())) {
            //支付宝支付
            payment.setPayType("ALIPAY_H5");
        }
        payment.setNotifyUrl(notifyUrl);
        return payOrderService.pay(payment);
    }

    /**
     * 判断此次支付是否完成
     */
    @ApiOperation("判断此次支付是否完成")
    @GetMapping("/payWhetherSuccess")
    public ResponseJson<String> payWhetherSuccess(Integer orderId, Integer paySuccessCounter) {
        if (null == orderId || null == paySuccessCounter) {
            return ResponseJson.error("参数异常", null);
        }
        return payOrderService.payWhetherSuccess(orderId, paySuccessCounter);
    }

    /**
     * 查询本次支付订单是否完成
     */
    @GetMapping("/findOrderStatus")
    public ResponseJson<JSONObject> findOrderStatus(String mbOrderId) {
        if (null == mbOrderId) {
            return ResponseJson.error("参数异常", null);
        }
        return payOrderService.findOrderStatus(mbOrderId);
    }
}
